<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="en_GB">
<context>
    <name>CBoatElementWidget</name>
    <message>
        <location filename="../boatdef-panel.cpp" line="137"/>
        <source>Sail information</source>
        <translation type="obsolete">Seilinformasjon</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="145"/>
        <source>file</source>
        <translation>fil</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="146"/>
        <source>name</source>
        <translation>navn</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="147"/>
        <source>Reload</source>
        <translation>Forny</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="148"/>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="149"/>
        <source>Update</source>
        <translation>Oppdater</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="144"/>
        <source>Element information</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFileIO</name>
    <message>
        <location filename="" line="7667811"/>
        <source>Open</source>
        <translation type="obsolete">åpne</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Save</source>
        <translation type="obsolete">Lagre</translation>
    </message>
</context>
<context>
    <name>CFileWriter</name>
    <message>
        <location filename="../filewriter.h" line="129"/>
        <source>error</source>
        <translation>feil</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="129"/>
        <source>There was an error writing to the selected file.</source>
        <translation>Feil ved utskrivning av valgte fil.</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="66"/>
        <source>Open</source>
        <translation>åpne</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="88"/>
        <source>There was an error reading from the selected file.</source>
        <translation>Feil ved lesning av valgte fil.</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="105"/>
        <source>Save</source>
        <translation>Lagre</translation>
    </message>
</context>
<context>
    <name>CFormBoat</name>
    <message>
        <location filename="../formboat.cpp" line="104"/>
        <source>boat</source>
        <translation>båten</translation>
    </message>
    <message>
        <location filename="../formboat.cpp" line="105"/>
        <source>&amp;Add</source>
        <translation>&amp;Legg</translation>
    </message>
    <message>
        <location filename="../formboat.cpp" line="106"/>
        <source>file</source>
        <translation>fil</translation>
    </message>
    <message>
        <location filename="../formboat.cpp" line="167"/>
        <source>Open</source>
        <translation>åpne</translation>
    </message>
</context>
<context>
    <name>CFormHelp</name>
    <message>
        <location filename="../formhelp.cpp" line="68"/>
        <source>Sailcut CAD Handbook</source>
        <translation>Sailcut CAD Håndbok</translation>
    </message>
</context>
<context>
    <name>CFormHull</name>
    <message>
        <location filename="../formhull.cpp" line="57"/>
        <source>hull</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhull.cpp" line="58"/>
        <source>&amp;Dimensions</source>
        <translation>&amp;Dimensjoner</translation>
    </message>
</context>
<context>
    <name>CFormHullDefBase</name>
    <message>
        <location filename="../formhulldefbase.ui" line="20"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="42"/>
        <source>Deck and bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="60"/>
        <source>Planking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="72"/>
        <source>Automatic planking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="123"/>
        <source>lower plank angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="187"/>
        <source>top plank angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="194"/>
        <source>Number of planks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="212"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="269"/>
        <source>Bottom sweep angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="290"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="402"/>
        <source>Max Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="611"/>
        <source>Forward shape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="618"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="633"/>
        <source>Forward height </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="640"/>
        <source>Max Width position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="662"/>
        <source>Stem angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="669"/>
        <source>Transom angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1639"/>
        <source>Aft height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="691"/>
        <source>Aft width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="698"/>
        <source>Aft shape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="760"/>
        <source>Hull name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="770"/>
        <source>Deck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1646"/>
        <source>Forward height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="891"/>
        <source>Plank 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1618"/>
        <source>Chine angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1625"/>
        <source>Sweep angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1632"/>
        <source>Plank angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1034"/>
        <source>Plank 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1177"/>
        <source>Plank 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1320"/>
        <source>Plank 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1463"/>
        <source>Plank 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1606"/>
        <source>Plank 6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1774"/>
        <source>Check</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1781"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1788"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1817"/>
        <source>Dimensions are in millimeters and angles in degrees measured from horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="879"/>
        <source>Planks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="395"/>
        <source>txt_BBW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="423"/>
        <source>txt_BfwdHeight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="444"/>
        <source>txt_BLWL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="465"/>
        <source>txt_BaftW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="559"/>
        <source>txt_BaftHeight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="604"/>
        <source>Dead rise angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="745"/>
        <source>txt_HullID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="826"/>
        <source>txt_DaftHeight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="847"/>
        <source>txt_DfwdHeight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="861"/>
        <source>Side angle</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFormMain</name>
    <message>
        <location filename="" line="7667811"/>
        <source>to &amp;DXF</source>
        <translation type="obsolete">&amp;DXF</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>to &amp;TXT sail</source>
        <translation type="obsolete">seil &amp;TXT</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>to &amp;XML sail</source>
        <translation type="obsolete">seil &amp;XML</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="131"/>
        <source>&amp;New</source>
        <translation>&amp;Ny</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="136"/>
        <source>&amp;Open</source>
        <translation>&amp;åpne</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="138"/>
        <source>&amp;Save</source>
        <translation>&amp;Lagre</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="139"/>
        <source>Save &amp;As</source>
        <translation>Lagre &amp;som</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="141"/>
        <source>&amp;Quit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>&amp;Dimensions</source>
        <translation type="obsolete">&amp;Dimensjoner</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>&amp;Mould</source>
        <translation type="obsolete">&amp;Mal</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>&amp;Patches</source>
        <translation type="obsolete">&amp;Lapper</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>&amp;Rig</source>
        <translation type="obsolete">&amp;Rigg</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="129"/>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="144"/>
        <source>&amp;View</source>
        <translation>&amp;Bilde</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="155"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="334"/>
        <source>About Sailcut CAD</source>
        <translation>Informasjon om Sailcut CAD</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>error</source>
        <translation type="obsolete">feil</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>There was an error writing to the selected file</source>
        <translation type="obsolete">Feil ved utskrivning av valgte fil.</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="157"/>
        <source>About &amp;Qt</source>
        <translation>Informasjon om &amp;Qt</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="158"/>
        <source>About &amp;Sailcut CAD</source>
        <translation>Informasjon om &amp;Sailcut CAD</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="145"/>
        <source>Language</source>
        <translation>Språk</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="137"/>
        <source>Open &amp;recent</source>
        <translation>Åpne &amp;siste</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>E&amp;xport 3D sail</source>
        <translation type="obsolete">&amp;Eksporter 3D seil</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>to &amp;Carlson plotter</source>
        <translation type="obsolete">til &amp;Carlson plotter</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Export &amp;development</source>
        <translation type="obsolete">Eksporter &amp;utvikling</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="156"/>
        <source>Sailcut CAD &amp;Handbook</source>
        <translation>Sailcut &amp;Håndbok CAD</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>shaded view</source>
        <translation type="obsolete">visning i 3D</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>wireframe view</source>
        <translation type="obsolete">visning av omriss</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>development</source>
        <translation type="obsolete">utskytningsoversikt</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>created new sail</source>
        <translation type="obsolete">laget nytt seil</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="215"/>
        <source>loaded &apos;%1&apos;</source>
        <translation>lastet inn &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="220"/>
        <source>error loading &apos;%1&apos;</source>
        <translation>feil ved lasting av &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="504"/>
        <source>wrote &apos;%1&apos;</source>
        <translation>skrev &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>There was a data printing error</source>
        <translation type="obsolete">Feil ved utskrift av data</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>There was a development printing error</source>
        <translation type="obsolete">Feil ved utskrift av paneler</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>There was a drawing printing error</source>
        <translation type="obsolete">Feil ved utskrift av tegning</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>data</source>
        <translation type="obsolete">data</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>drawing</source>
        <translation type="obsolete">tegning</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>develop</source>
        <translation type="obsolete">lag paneler</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>&amp;Print</source>
        <translation type="obsolete">&amp;Skriv ut</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Sail type</source>
        <translation type="obsolete">Seiltype</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Mainsail</source>
        <translation type="obsolete">Storseil</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Jib</source>
        <translation type="obsolete">Fokke</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Sail layout</source>
        <translation type="obsolete">Seil layout</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Cross Cut</source>
        <translation type="obsolete">Kryss kutt</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Horizontal Cut</source>
        <translation type="obsolete">Horisontalt kutt</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Radial Cut</source>
        <translation type="obsolete">Radial kutt</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Twist Foot Cut</source>
        <translation type="obsolete">Vridd underlik kutt</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Vertical Cut</source>
        <translation type="obsolete">Vertikalt kutt</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Mitre Cut</source>
        <translation type="obsolete">Mitre kutt</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source> sections,   </source>
        <translation type="obsolete">baner</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source> head gores.</source>
        <translation type="obsolete">Antall paneler i topp.</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Rig </source>
        <translation type="obsolete">Rigg</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Boat LOA</source>
        <translation type="obsolete">Båtens LOA</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Fore triangle hoist I</source>
        <translation type="obsolete">Høyde I av framre trekant</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Fore triangle base J</source>
        <translation type="obsolete">Foten J av framre trekant</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Tack position X</source>
        <translation type="obsolete">Nedhalets posisjon X</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Tack height Y</source>
        <translation type="obsolete">Nedhalets høyde Y</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Sail dimensions</source>
        <translation type="obsolete">Seil dimensjoner</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Luff length</source>
        <translation type="obsolete">Forlikets lengde</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Gaff angle wrt luff</source>
        <translation type="obsolete">Gaffelens vinkel på forliket</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Gaff length</source>
        <translation type="obsolete">Gaffel lengde</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Foot length</source>
        <translation type="obsolete">Lengde underkant</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Leech length</source>
        <translation type="obsolete">Akterlikets lengde</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Shape of edges</source>
        <translation type="obsolete">Form på seilets lik</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Luff round</source>
        <translation type="obsolete">Forlikets avrunding</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Gaff round</source>
        <translation type="obsolete">Gaffel avrunding</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Leech round</source>
        <translation type="obsolete">Akterlikets avrunding</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Foot round</source>
        <translation type="obsolete">Underlikets avrunding</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Luff round position</source>
        <translation type="obsolete">Plassering av forlikets avrunding</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Gaff round position</source>
        <translation type="obsolete">Plassering av gaffelens avrunding</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Leech round position</source>
        <translation type="obsolete">Plassering av akterlikets avrunding</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Foot round position</source>
        <translation type="obsolete">Plassering av underlikets avrunding</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Sail settings</source>
        <translation type="obsolete">Innstillinger for seil</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Twist angle</source>
        <translation type="obsolete">Tvist vinkel</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Sheeting angle</source>
        <translation type="obsolete">Skjøtevinkel</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Cloth seams and hems</source>
        <translation type="obsolete">Stoff søm og bretter</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Cloth width</source>
        <translation type="obsolete">Stoff bredde</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Seams width</source>
        <translation type="obsolete">Søm bredde</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Leech hem width</source>
        <translation type="obsolete">Bredde på akterlikets søm</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Other hem width</source>
        <translation type="obsolete">Bredde på andre sømmer</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Sail mould</source>
        <translation type="obsolete">Seil mal</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Luff factor</source>
        <translation type="obsolete">Forlikets faktor</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Depth</source>
        <translation type="obsolete">Dybde</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Leech factor</source>
        <translation type="obsolete">Akterlikets faktor</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Top profile</source>
        <translation type="obsolete">Topp profil</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Mid profile at h = </source>
        <translation type="obsolete">Midtre profil  h =</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Bottom profile</source>
        <translation type="obsolete">Nedre profil</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Mast/Luff rake</source>
        <translation type="obsolete">Mastelogg</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source> head gores,   </source>
        <translation type="obsolete"> Antall paneler i topp,   </translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Wing</source>
        <translation type="obsolete">Vinge</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source> luff gores.</source>
        <translation type="obsolete">baner i forlik.</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>deg</source>
        <translation type="obsolete">grad</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="132"/>
        <source>sail</source>
        <translation>seil</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="133"/>
        <source>hull</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="134"/>
        <source>rig</source>
        <translation>rigg</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="135"/>
        <source>boat</source>
        <translation>båten</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="148"/>
        <source>&amp;Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="149"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="150"/>
        <source>Close &amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="151"/>
        <source>&amp;Tile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="152"/>
        <source>&amp;Cascade</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="207"/>
        <source>unknown document type &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="461"/>
        <source>Open</source>
        <translation>åpne</translation>
    </message>
</context>
<context>
    <name>CFormMould</name>
    <message>
        <location filename="../formmould.cpp" line="60"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="66"/>
        <source>Vertical repartition</source>
        <translation>Vertikal oppdeling</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="42"/>
        <source>Sail mould</source>
        <translation>Seil mal</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>&amp;Help</source>
        <translation type="obsolete">Hjelp</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="56"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="77"/>
        <source>Top profile</source>
        <translation>Topp profil</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="78"/>
        <source>Middle profile</source>
        <translation>Mitre profil</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="79"/>
        <source>Bottom profile</source>
        <translation>Nedre profil</translation>
    </message>
</context>
<context>
    <name>CFormPanelGroup</name>
    <message>
        <location filename="../formpanelgroup.cpp" line="56"/>
        <source>panels</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFormRig</name>
    <message>
        <location filename="" line="7667811"/>
        <source>Rig</source>
        <translation type="obsolete">Rigg</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>&amp;New</source>
        <translation type="obsolete">&amp;Ny</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>sail &amp;definition</source>
        <translation type="obsolete">seil &amp;definisjoner</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>3D &amp;sail</source>
        <translation type="obsolete">3D &amp;seil</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>&amp;Add sail</source>
        <translation type="obsolete">&amp;Legg til seil</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>&amp;Open</source>
        <translation type="obsolete">&amp;åpne</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Open &amp;recent</source>
        <translation type="obsolete">Åpne &amp;siste</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>&amp;Save</source>
        <translation type="obsolete">&amp;Lagre</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Save &amp;As</source>
        <translation type="obsolete">Lagre &amp;som</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Lukk</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>&amp;File</source>
        <translation type="obsolete">&amp;Fil</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>error</source>
        <translation type="obsolete">feil</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>There was an error writing to the selected file</source>
        <translation type="obsolete">Feil ved utskrivning av valgte fil</translation>
    </message>
    <message>
        <location filename="../formrig.cpp" line="59"/>
        <source>rig</source>
        <translation>rigg</translation>
    </message>
    <message>
        <location filename="../formrig.cpp" line="60"/>
        <source>&amp;Dimensions</source>
        <translation>&amp;Dimensjoner</translation>
    </message>
</context>
<context>
    <name>CFormRigDefBase</name>
    <message>
        <location filename="../formrigdefbase.ui" line="20"/>
        <source>Rig dimensions</source>
        <translation>Rigg dimensjoner</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="53"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="68"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="75"/>
        <source>Spreaders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="122"/>
        <source>= SPNB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="129"/>
        <source>Number of spreaders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="147"/>
        <source>Spreader height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="173"/>
        <source>txt_SPH2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="197"/>
        <source>txt_SPH1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="221"/>
        <source>txt_SPH3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="231"/>
        <source>SPH2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="238"/>
        <source>SPH3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="245"/>
        <source>SPH1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="255"/>
        <source>Spreader length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="267"/>
        <source>SPW3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="280"/>
        <source>txt_SPW3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="290"/>
        <source>SPW1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="303"/>
        <source>txt_SPW1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="313"/>
        <source>SPW2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="326"/>
        <source>txt_SPW2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="350"/>
        <source>Shrouds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="376"/>
        <source>Cap shroud base width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="397"/>
        <source>= CSH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="418"/>
        <source>Lower shroud base width </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="439"/>
        <source>txt_LSB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="463"/>
        <source>txt_CSH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="487"/>
        <source>= CSB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="508"/>
        <source>Cap shroud height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="529"/>
        <source>txt_CSB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="553"/>
        <source>= LSB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="587"/>
        <source>Fore triangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="626"/>
        <source>txt_foreI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="636"/>
        <source>= I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="657"/>
        <source>txt_foreJ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="667"/>
        <source>= J</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="674"/>
        <source>Fore triangle base</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="681"/>
        <source>Fore triangle hoist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="691"/>
        <source>Mast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="703"/>
        <source>Mast width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="710"/>
        <source>= MW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="723"/>
        <source>txt_MW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="739"/>
        <source>txt_MC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="749"/>
        <source>= MC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="756"/>
        <source>Mast cord</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="766"/>
        <source>lbl_MRkD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="776"/>
        <source>= MRkD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="783"/>
        <source>Mast rake angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="804"/>
        <source>txt_MH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="814"/>
        <source>txt_MRnd</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="840"/>
        <source>Mast rake</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="847"/>
        <source>= MRkM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="868"/>
        <source>txt_MRkM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="892"/>
        <source>Mast height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="899"/>
        <source>= MH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="906"/>
        <source>= MRnd</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="927"/>
        <source>Mast round</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="934"/>
        <source>= MRndPos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="955"/>
        <source>Mast round position </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1015"/>
        <source>Mainsail</source>
        <translation>Storseil</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1044"/>
        <source>lbl_MS_LuffRP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1068"/>
        <source>@ </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1095"/>
        <source>lbl_MS_LuffR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1122"/>
        <source>lbl_MS_TackY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1146"/>
        <source>Y =</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1173"/>
        <source>lbl_MS_TackX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1191"/>
        <source>X =</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1209"/>
        <source>Tack</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1249"/>
        <source>lbl_MS_LuffL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1267"/>
        <source>= MSL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1288"/>
        <source>Luff length </source>
        <translation>Forlikets lengde</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1309"/>
        <source>Luff round</source>
        <translation>Forlikets avrunding</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1333"/>
        <source>lbl_MS_Rake</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1351"/>
        <source>= MSR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1372"/>
        <source>Luff rake</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1409"/>
        <source>Tack height </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1430"/>
        <source>txt_BAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1454"/>
        <source>= BAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1476"/>
        <source>Head height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1491"/>
        <source>= HAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1512"/>
        <source>txt_HAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1538"/>
        <source>Check</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1572"/>
        <source>All dimensions are in millimeter and angles in degrees</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1602"/>
        <source>Rig ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1618"/>
        <source>Description of rig</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFormSail</name>
    <message>
        <location filename="../formsail.cpp" line="73"/>
        <source>sail</source>
        <translation>seil</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="76"/>
        <source>&amp;Print</source>
        <translation>&amp;Skriv ut</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="77"/>
        <source>data</source>
        <translation>data</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="78"/>
        <source>drawing</source>
        <translation>tegning</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="106"/>
        <source>development</source>
        <translation>utskytningsoversikt</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="82"/>
        <source>E&amp;xport 3D sail</source>
        <translation>&amp;Eksporter 3D seil</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="93"/>
        <source>to &amp;DXF</source>
        <translation>&amp;DXF</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="96"/>
        <source>to &amp;TXT sail</source>
        <translation>seil &amp;TXT</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="97"/>
        <source>to &amp;XML sail</source>
        <translation>seil &amp;XML</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="91"/>
        <source>Export &amp;development</source>
        <translation>Eksporter &amp;utvikling</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="92"/>
        <source>to &amp;Carlson plotter</source>
        <translation>til &amp;Carlson plotter</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="95"/>
        <source>to &amp;Hand-plotting format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="100"/>
        <source>&amp;Dimensions</source>
        <translation>&amp;Dimensjoner</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="101"/>
        <source>&amp;Mould</source>
        <translation>&amp;Mal</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="102"/>
        <source>&amp;Patches</source>
        <translation>&amp;Lapper</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="393"/>
        <source>error</source>
        <translation>feil</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="336"/>
        <source>There was a data printing error</source>
        <translation>Feil ved utskrift av data</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="365"/>
        <source>There was a development printing error</source>
        <translation>Feil ved utskrift av paneler</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="393"/>
        <source>There was a drawing printing error</source>
        <translation>Feil ved utskrift av tegning</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="85"/>
        <source>to &amp;SVG</source>
        <translation>&amp;SVG</translation>
    </message>
</context>
<context>
    <name>CFormSailDef</name>
    <message>
        <location filename="../formsaildef.cpp" line="1090"/>
        <source>Sail corners coordinates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1091"/>
        <source>tack</source>
        <translation>høyde</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1092"/>
        <source>clew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1093"/>
        <source>head</source>
        <translation>topp</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1094"/>
        <source>peak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1099"/>
        <source>Sail width measurements </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFormSailDefBase</name>
    <message>
        <location filename="../formsaildefbase.ui" line="19"/>
        <source>Sail definition</source>
        <translation>Definisjon av seilet</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="315"/>
        <source>Sail dimensions</source>
        <translation>Seil dimensjoner</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="793"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="448"/>
        <source>Round position</source>
        <translation>Posisjonen til avrundingen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="406"/>
        <source>Luff length</source>
        <translation>Forlikets lengde</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="413"/>
        <source>Foot length</source>
        <translation>Lengde underkant</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="427"/>
        <source>Leech length</source>
        <translation>Akterlikets lengde</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="455"/>
        <source>Gaff length</source>
        <translation>Gaffel lengde</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="462"/>
        <source>Leech round</source>
        <translation>Akterlikets avrunding</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="578"/>
        <source>Gaff round</source>
        <translation>Gaffel avrunding</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="469"/>
        <source>Luff round</source>
        <translation>Forlikets avrunding</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="476"/>
        <source>Foot round</source>
        <translation>Underlikets avrunding</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="870"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="940"/>
        <source>deg</source>
        <translation>grad</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="585"/>
        <source>Gaff angle from luff</source>
        <translation>Gaffel vinkel/forlik</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="69"/>
        <source>Rig geometry</source>
        <translation>Riggens Mål</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="271"/>
        <source>Fore triangle base  J</source>
        <translation>Foten J av framre trekant</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="285"/>
        <source>Tack height</source>
        <translation>Høyde på skjøtefeste</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="264"/>
        <source>Distance tack to stem</source>
        <translation>Avstand fra nedhal til skjøtefeste</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="229"/>
        <source>Main sail</source>
        <translation>Storseil</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="119"/>
        <source>Jib</source>
        <translation>Fokke</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="292"/>
        <source>Fore triangle hoist  I</source>
        <translation>Høyde I av framre trekant</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="257"/>
        <source>Boat length LOA</source>
        <translation>Lengde på båten</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="278"/>
        <source>Mast / Luff rake</source>
        <translation>Mastelogg</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="725"/>
        <source>Cloth</source>
        <translation>Stoff</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="800"/>
        <source>Seam width</source>
        <translation>Søm bredde</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="765"/>
        <source>Cloth width</source>
        <translation>Stoff bredde</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="950"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="962"/>
        <source>Mitre cut</source>
        <translation>Mitre kutt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="969"/>
        <source>Cross cut</source>
        <translation>Kryss kutt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="976"/>
        <source>Twist foot</source>
        <translation>Vridd underlik</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1045"/>
        <source>Horizontal cut</source>
        <translation>Horisontalt kutt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1010"/>
        <source>Number of sections</source>
        <translation>Antall baner</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1031"/>
        <source>Number of radial gores</source>
        <translation>Antall radial paneler</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="990"/>
        <source>Radial cut</source>
        <translation>Radial kutt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="983"/>
        <source>Vertical cut</source>
        <translation>Vertikal kutt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="824"/>
        <source>Sail shape</source>
        <translation>Seilets form</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="884"/>
        <source>Top depth</source>
        <translation>Dybde i toppen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="891"/>
        <source>Mid depth</source>
        <translation>Dybde på midten</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="898"/>
        <source>Foot depth</source>
        <translation>Dybde ved underliket</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="919"/>
        <source>Twist angle</source>
        <translation>Tvist vinkel</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1074"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="702"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="779"/>
        <source>Leech hem</source>
        <translation>Bretten på akterliket</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="786"/>
        <source>Other hems</source>
        <translation>Andre brett kanter</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="926"/>
        <source>Sheeting angle</source>
        <translation>Skjøtevinkel</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="" line="7667811"/>
        <source>m²</source>
        <translation type="obsolete">m²</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="669"/>
        <source>Sail area</source>
        <translation>Seilets areal</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="662"/>
        <source>Diagonal</source>
        <translation>Diagonal</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1081"/>
        <source>Compute</source>
        <translation>Beregn</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="56"/>
        <source>Sail ID</source>
        <translation>Seil ID</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1038"/>
        <source>Number of luff gores</source>
        <translation>Antall baner i forlik</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="98"/>
        <source>Dihedral angle</source>
        <translation>Vinkel</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="105"/>
        <source>Wing</source>
        <translation>Vinge</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="31"/>
        <source>Sail identifier</source>
        <translation>Seil ID</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="692"/>
        <source>m2</source>
        <translation>m2</translation>
    </message>
</context>
<context>
    <name>CRigSailWidget</name>
    <message>
        <location filename="" line="7667811"/>
        <source>Sail information</source>
        <translation type="obsolete">Seilinformasjon</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>file</source>
        <translation type="obsolete">fil</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>name</source>
        <translation type="obsolete">navn</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Reload</source>
        <translation type="obsolete">Forny</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Remove</source>
        <translation type="obsolete">Fjern</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>Update</source>
        <translation type="obsolete">Oppdater</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>error</source>
        <translation type="obsolete">feil</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>There was an error reading from the selected file.</source>
        <translation type="obsolete">Feil ved lesning av valgte fil.</translation>
    </message>
</context>
<context>
    <name>CSailDispGL</name>
    <message>
        <location filename="" line="7667811"/>
        <source>This system has no OpenGL support.</source>
        <translation type="obsolete">OpenGL er ikke tilgjengelig.</translation>
    </message>
</context>
<context>
    <name>CSailPrinter</name>
    <message>
        <location filename="../sailprinter.cpp" line="152"/>
        <source>Sailcut CAD data sheet</source>
        <translation>Sailcut CAD kuttliste</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="158"/>
        <source>Mainsail</source>
        <translation>Storseil</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="161"/>
        <source>Jib</source>
        <translation>Fokke</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="164"/>
        <source>Wing</source>
        <translation>Vinge</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="164"/>
        <source>deg</source>
        <translation>grad</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="167"/>
        <source>Sail type</source>
        <translation>Seiltype</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="173"/>
        <source>Cross Cut</source>
        <translation>Kryss kutt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="176"/>
        <source>Horizontal Cut</source>
        <translation>Horisontalt kutt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="179"/>
        <source>Radial Cut</source>
        <translation>Radial kutt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="180"/>
        <source>sections</source>
        <translation>baner</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="181"/>
        <source>head gores</source>
        <translation>topp baner</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="182"/>
        <source>luff gores</source>
        <translation>forlik baner</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="185"/>
        <source>Twist Foot Cut</source>
        <translation>Vridd underlik kutt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="188"/>
        <source>Vertical Cut</source>
        <translation>Vertikalt kutt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="191"/>
        <source>Mitre Cut</source>
        <translation>Mitre kutt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="194"/>
        <source>Sail layout</source>
        <translation>Seil layout</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="197"/>
        <source>Rig</source>
        <translation>Rigg</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="198"/>
        <source>Boat LOA</source>
        <translation>Båtens LOA</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="199"/>
        <source>Mast/Luff rake</source>
        <translation>Mastelogg</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="200"/>
        <source>Tack position X</source>
        <translation>Nedhalets posisjon X</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="201"/>
        <source>Tack height Y</source>
        <translation>Nedhalets høyde Y</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="202"/>
        <source>Fore triangle hoist I</source>
        <translation>Høyde I av framre trekant</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="203"/>
        <source>Fore triangle base J</source>
        <translation>Foten J av framre trekant</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="206"/>
        <source>Sail dimensions</source>
        <translation>Seil dimensjoner</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="207"/>
        <source>Luff length</source>
        <translation>Forlikets lengde</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="208"/>
        <source>Foot length</source>
        <translation>Lengde underkant</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="209"/>
        <source>Leech length</source>
        <translation>Akterlikets lengde</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="210"/>
        <source>Gaff length</source>
        <translation>Gaffel lengde</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="211"/>
        <source>Gaff angle wrt luff</source>
        <translation>Gaffelens vinkel på forliket</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="214"/>
        <source>Shape of edges</source>
        <translation>Form på seilets lik</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="215"/>
        <source>Luff round</source>
        <translation>Forlikets avrunding</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="216"/>
        <source>Luff round position</source>
        <translation>Plassering av forlikets avrunding</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="217"/>
        <source>Foot round</source>
        <translation>Underlikets avrunding</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="218"/>
        <source>Foot round position</source>
        <translation>Plassering av underlikets avrunding</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="219"/>
        <source>Leech round</source>
        <translation>Akterlikets avrunding</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="220"/>
        <source>Leech round position</source>
        <translation>Plassering av akterlikets avrunding</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="221"/>
        <source>Gaff round</source>
        <translation>Gaffel avrunding</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="222"/>
        <source>Gaff round position</source>
        <translation>Plassering av gaffelens avrunding</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="225"/>
        <source>Sail settings</source>
        <translation>Innstillinger for seil</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="226"/>
        <source>Twist angle</source>
        <translation>Tvist vinkel</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="227"/>
        <source>Sheeting angle</source>
        <translation>Skjøtevinkel</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="230"/>
        <source>Cloth seams and hems</source>
        <translation>Stoff søm og bretter</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="231"/>
        <source>Cloth width</source>
        <translation>Stoff bredde</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="232"/>
        <source>Seams width</source>
        <translation>Søm bredde</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="233"/>
        <source>Leech hem width</source>
        <translation>Bredde på akterlikets søm</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="234"/>
        <source>Other hem width</source>
        <translation>Bredde på andre sømmer</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="237"/>
        <source>Sail mould</source>
        <translation>Seil mal</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="238"/>
        <source>Luff factor</source>
        <translation>Forlikets faktor</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="238"/>
        <source>Depth</source>
        <translation>Dybde</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="238"/>
        <source>Leech factor</source>
        <translation>Akterlikets faktor</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="240"/>
        <source>Top profile</source>
        <translation>Topp profil</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="246"/>
        <source>Mid profile at h = </source>
        <translation>Midtre profil  h =</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="252"/>
        <source>Bottom profile</source>
        <translation>Nedre profil</translation>
    </message>
</context>
<context>
    <name>CSailViewerPanel</name>
    <message>
        <location filename="../sailviewer-panel.cpp" line="137"/>
        <source>Display parameters</source>
        <translation>Vis parametrene</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="138"/>
        <source>elevation</source>
        <translation>elevasjon</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="139"/>
        <source>azimuth</source>
        <translation>azimuth</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="141"/>
        <source>Controls</source>
        <translation>Kontroller</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="142"/>
        <source>Reset view</source>
        <translation>Forny bildet</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="145"/>
        <source>Labeling</source>
        <translation>Etiketter</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="147"/>
        <source>Zoom in</source>
        <translation>Zoom in</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="148"/>
        <source>Zoom out</source>
        <translation>Zoom ut</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="186"/>
        <source>deg</source>
        <translation>grader</translation>
    </message>
</context>
<context>
    <name>CSailViewerTabs</name>
    <message>
        <location filename="../sailviewer-tabs.cpp" line="64"/>
        <source>shaded view</source>
        <translation>visning i 3D</translation>
    </message>
    <message>
        <location filename="../sailviewer-tabs.cpp" line="66"/>
        <source>wireframe view</source>
        <translation>visning av omriss</translation>
    </message>
</context>
<context>
    <name>CWidgetProfile</name>
    <message>
        <location filename="../widgetprofile.cpp" line="242"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="240"/>
        <source>Luff shape</source>
        <translation>Forlikets form</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="241"/>
        <source>Depth</source>
        <translation>Dybde</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="243"/>
        <source>Leech shape</source>
        <translation>Akterlikets form</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="247"/>
        <source>degrees</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="246"/>
        <source>cord</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XmlReaderTempl</name>
    <message>
        <location filename="" line="7667811"/>
        <source>error</source>
        <translation type="obsolete">feil</translation>
    </message>
    <message>
        <location filename="" line="7667811"/>
        <source>There was an error reading from the selected file.</source>
        <translation type="obsolete">Feil ved lesning av valgte fil.</translation>
    </message>
</context>
</TS>
